<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ays-pro.com
 * @since      1.0.0
 *
 * @package    Personal_Dictionary
 * @subpackage Personal_Dictionary/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Personal_Dictionary
 * @subpackage Personal_Dictionary/admin
 * @author     Personal Dictionary Team <info@ays-pro.com>
 */
class Personal_Dictionary_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	public function admin_menu_styles(){
        
        echo "<style>
            
            #adminmenu a.toplevel_page_personal-dictionary div.wp-menu-image img {
                width: 32px;
                padding: 1px 0 0;
                transition: .3s ease-in-out;
            }
        </style>";
    }

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles($hook_suffix) {

		wp_enqueue_style($this->plugin_name . '-admin', plugin_dir_url(__FILE__) . 'css/admin.css', array(), $this->version, 'all');
		wp_enqueue_style( $this->plugin_name .'-banner', plugin_dir_url( __FILE__ ) . 'css/personal-dictionary-banner.css', array(), $this->version, 'all' );
		        
        if (false !== strpos($hook_suffix, "plugins.php")){
            wp_enqueue_style( $this->plugin_name . '-sweetalert-css', PERSONAL_DICTIONARY_PUBLIC_URL . '/css/personal-dictionary-sweetalert2.min.css', array(), $this->version, 'all');
        }

		if (false === strpos($hook_suffix, $this->plugin_name))
            return;
		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Personal_Dictionary_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Personal_Dictionary_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		wp_enqueue_style( $this->plugin_name . '-bootstrap', plugin_dir_url(__FILE__) . 'css/bootstrap.min.css', array(), $this->version, 'all');
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/personal-dictionary-admin.css', array(), $this->version, 'all' );
		wp_enqueue_style($this->plugin_name . '-font-awesome', plugin_dir_url(__FILE__) . '/css/personal-dictionary-font-awesome.min.css', array(), $this->version, 'all');
		wp_enqueue_style($this->plugin_name . '-fonts', plugin_dir_url(__FILE__) . '/css/personal-dictionary-fonts.css', array(), $this->version, 'all');

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts($hook_suffix) {
		wp_enqueue_script('jquery');

		wp_enqueue_script( $this->plugin_name .'-banner', plugin_dir_url( __FILE__ ) . 'js/personal-dictionary-banner.js', array( 'jquery' ), $this->version, true );

		if (false !== strpos($hook_suffix, "plugins.php")){
            wp_enqueue_script( $this->plugin_name . '-sweetalert-js', PERSONAL_DICTIONARY_PUBLIC_URL . '/js/personal-dictionary-sweetalert2.all.min.js', array('jquery'), $this->version, true );
            wp_enqueue_script( $this->plugin_name . '-admin', plugin_dir_url(__FILE__) . 'js/admin.js', array( 'jquery' ), $this->version, true );
            wp_localize_script( $this->plugin_name . '-admin', 'PersonalDictionaryAdmin', array( 
            	'ajaxUrl' => admin_url( 'admin-ajax.php' )
            ) );
        }

		if (false === strpos($hook_suffix, $this->plugin_name))
            return;

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Personal_Dictionary_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Personal_Dictionary_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */


		wp_enqueue_style('wp-color-picker');
		wp_enqueue_script( $this->plugin_name . '-wp-color-picker-alpha', plugin_dir_url(__FILE__) . 'js/wp-color-picker-alpha.min.js', array('wp-color-picker'), $this->version, true);
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/personal-dictionary-admin.js', array( 'jquery' ), $this->version, false );
		wp_enqueue_script( $this->plugin_name . '-pd-popper', plugin_dir_url(__FILE__) . 'js/popper.min.js', array('jquery'), $this->version, true);
		wp_enqueue_script( $this->plugin_name."-pd-bootstrap", plugin_dir_url( __FILE__ ) . 'js/bootstrap.min.js', array( 'jquery' ), $this->version, true );

        $pd_banner_date = $this->ays_pd_update_banner_time();
		wp_localize_script( $this->plugin_name, 'pdAdminLangObj', array(
            'pdBannerDate'  => $pd_banner_date,
            'copied'        => __( 'Copied!', $this->plugin_name),
            'clickForCopy'  => __( 'Click for copy.', $this->plugin_name),
        ) );       

        wp_localize_script( $this->plugin_name, 'PersonalDictionaryAdmin', array(
            'addImage'	=> __( 'Add Image', $this->plugin_name ),
            'editImage'	=> __( 'Edit Image', $this->plugin_name ),            
        ) );
		
		$color_picker_strings = array(
			'clear'            => __( 'Clear', $this->plugin_name ),
			'clearAriaLabel'   => __( 'Clear color', $this->plugin_name ),
			'defaultString'    => __( 'Default', $this->plugin_name ),
			'defaultAriaLabel' => __( 'Select default color', $this->plugin_name ),
			'pick'             => __( 'Select Color', $this->plugin_name ),
			'defaultLabel'     => __( 'Color value', $this->plugin_name ),
		);
		wp_localize_script( $this->plugin_name . '-wp-color-picker-alpha', 'wpColorPickerL10n', $color_picker_strings );

	}

	public function codemirror_enqueue_scripts($hook) {
        if(strpos($hook, $this->plugin_name) !== false){
            if(function_exists('wp_enqueue_code_editor')){
                $cm_settings['codeEditor'] = wp_enqueue_code_editor(array(
                    'type' => 'text/css',
                    'codemirror' => array(
                        'inputStyle' => 'contenteditable',
                        'theme' => 'cobalt',
                    )
                ));

                wp_enqueue_script('wp-theme-plugin-editor');
                wp_localize_script('wp-theme-plugin-editor', 'cm_settings', $cm_settings);

                wp_enqueue_style('wp-codemirror');
            }
        }
    }

	//==== ADD MENU ====
	// Main Menu
	public function add_plugin_admin_menu(){

        /*
         * Add a settings page for this plugin to the Settings menu.
         *
         * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
         *
         *        Administration Menus: http://codex.wordpress.org/Administration_Menus
         *
         */
        add_menu_page(
            __('Dictionary', $this->plugin_name),
            __('Dictionary', $this->plugin_name),
            'manage_options',
            $this->plugin_name,
            array($this, 'display_plugin_pd_main_page'), 
			PERSONAL_DICTIONARY_ADMIN_URL . '/images/icons/logo-admin-32x32.png',
            6
        );
    }
	// Main submenu
	public function add_plugin_pd_submenu(){
        add_submenu_page(
            $this->plugin_name,
            __('Home', $this->plugin_name),
            __('Home', $this->plugin_name),
            'manage_options',
            $this->plugin_name,
            array($this, 'display_plugin_pd_main_page')
        );
    }
	// Reports submenu
	public function add_plugin_pd_reports_submenu(){
        add_submenu_page(
            $this->plugin_name,
            __('Reports', $this->plugin_name),
            __('Reports', $this->plugin_name),
            'manage_options',
            $this->plugin_name."-dictionary-reports",
            array($this, 'display_plugin_pd_reports_page')
        );
    }
    
	// Leaderboard submenu
	public function add_plugin_pd_leaderboard_submenu(){
		add_submenu_page(
			$this->plugin_name,
			__('Leaderboard', $this->plugin_name),
			__('Leaderboard', $this->plugin_name),
			'manage_options',
			$this->plugin_name."-dictionary-leaderboard",
			array($this, 'display_plugin_pd_leaderboard_page')
		);
	}

	// Settings submenu
	public function add_plugin_pd_settings_submenu(){
        add_submenu_page(
            $this->plugin_name,
            __('Settings', $this->plugin_name),
            __('Settings', $this->plugin_name),
            'manage_options',
            $this->plugin_name."-dictionary-settings",
            array($this, 'display_plugin_pd_settings_page')
        );
    }

	// How to use submenu
	public function add_plugin_pd_how_to_use_submenu(){
		add_submenu_page(
			$this->plugin_name,
			__('How to use', $this->plugin_name),
			__('How to use', $this->plugin_name),
			'manage_options',
			$this->plugin_name."-how-to-use",
			array($this, 'display_plugin_pd_how_to_use_page')
		);
	}

	// Our products submenu
	public function add_plugin_pd_our_products_submenu(){
        add_submenu_page(
            $this->plugin_name,
            __('Our products', $this->plugin_name),
            __('Our products', $this->plugin_name),
            'manage_options',
            $this->plugin_name."-our-products",
            array($this, 'display_plugin_pd_our_products_page')
        );
    }

	// PRO features submenu
	public function add_plugin_pd_our_pro_features_submenu(){
        add_submenu_page(
            $this->plugin_name,
            __('PRO features', $this->plugin_name),
            __('PRO features', $this->plugin_name),
            'manage_options',
            $this->plugin_name."-pro-features",
            array($this, 'display_plugin_pd_pro_features_page')
        );
    }


	public function add_action_links($links){
        /*
        *  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
        */
        $settings_link = array(
            '<a href="' . admin_url('admin.php?page=' . $this->plugin_name) . '">' . __('Settings', $this->plugin_name) . '</a>',
            '<a href="https://ays-demo.com/wordpress-personal-dictionary-plugin-demo/" target="_blank">' . __('Demo', $this->plugin_name) . '</a>',
            '<a href="https://ays-pro.com/wordpress/personal-dictionary" target="_blank" style="color:red;font-weight:bold;">' . __('Buy Now', $this->plugin_name) . '</a>',
        );
        return array_merge($settings_link, $links);

    }

	
 	public function add_plugin_row_meta($meta, $file) {

		if ($file == PERSONAL_DICTIONARY_BASENAME) {
			$meta[] = '<a href="https://wordpress.org/support/plugin/personal-dictionary/" target="_blank">' . esc_html__( 'Free Support', $this->plugin_name ) . '</a>';
		}

		return $meta;
	}

	public function ays_pd_sale_baner(){
		if(isset($_POST['ays_pd_sale_btn'])){
			update_option('ays_pd_sale_notification', 1);
			update_option('ays_pd_sale_date', current_time( 'mysql' ));
		}

		if(isset($_POST['ays_pd_sale_btn_for_two_months'])){
			update_option('ays_pd_sale_dismiss_for_two_month', 1);
			update_option('ays_pd_sale_date', current_time( 'mysql' ));
		}
	
		$ays_pd_sale_date = get_option('ays_pd_sale_date');
		$ays_pd_sale_two_months = get_option('ays_pd_sale_dismiss_for_two_month');

		$val = 60*60*24*5;
		if($ays_pd_sale_two_months == 1){
			$val = 60*60*24*61;
		}

		$current_date = current_time( 'mysql' );
		$date_diff = strtotime($current_date) - intval(strtotime($ays_pd_sale_date)) ;
		
		$days_diff = $date_diff / $val;
	
		if(intval($days_diff) > 0 ){
			update_option('ays_pd_sale_notification', 0);
			update_option('ays_pd_sale_dismiss_for_two_month', 0);
		}
	
		$ays_pd_ishmar = intval(get_option('ays_pd_sale_notification'));
		$ays_pd_ishmar += intval(get_option('ays_pd_sale_dismiss_for_two_month'));
		
		if($ays_pd_ishmar == 0 ){
			 if (isset($_GET['page'])){
				 if($_GET['page'] == 'personal-dictionary' || $_GET['page'] == 'personal-dictionary-dictionary-reports' || $_GET['page'] == 'personal-dictionary-dictionary-leaderboard' || $_GET['page'] == 'personal-dictionary-dictionary-settings' || $_GET['page'] == 'personal-dictionary-how-to-use' || $_GET['page'] == 'personal-dictionary-our-products' || $_GET['page'] == 'personal-dictionary-pro-features') {
					//$this->ays_pd_sale_message($ays_pd_ishmar);
					//$this->ays_pd_winter_bundle_message($ays_pd_ishmar);
					//$this->ays_pd_summer_bundle_message($ays_pd_ishmar);
					//$this->ays_pd_christmas_message($ays_pd_ishmar);
					$this->ays_pd_school_sale_message($ays_pd_ishmar);
				 }
			 }
		}
	}

	public static function ays_pd_school_sale_message($ishmar){
        if($ishmar == 0 ){
            $content = array();

            $content[] = '<div id="ays-pd-dicount-month-main" class="notice notice-success is-dismissible ays_pd_dicount_info">';
                $content[] = '<div id="ays-pd-dicount-month" class="ays_pd_dicount_month">';                    
                    $content[] = '<a href="https://ays-pro.com/school-bundle" target="_blank" class="ays-pd-sale-banner-link"><img src="' . PERSONAL_DICTIONARY_ADMIN_URL . '/images/school bundle.png"></a>';
                    $content[] = '<div class="ays-pd-dicount-wrap-box">';

                        $content[] = '<strong style="font-weight: bold;">';
                            $content[] = __( "Limited Time <span class='ays-pd-dicount-wrap-color'>50%</span> SALE on <br><span><a href='https://ays-pro.com/school-bundle' target='_blank' class='ays-pd-dicount-wrap-color ays-pd-dicount-wrap-text-decoration' style='display:block;'>School Bundle</a></span> (Quiz + Copy + Poll + Personal Dictionary)!", PERSONAL_DICTIONARY_NAME );
                        $content[] = '</strong>';
                        $content[] = '<br>';
                        $content[] = '<strong>';
                                $content[] = __( "Hurry up! <a href='https://ays-pro.com/school-bundle' target='_blank'>Check it out!</a>", PERSONAL_DICTIONARY_NAME );
                        $content[] = '</strong>';
                            
                    $content[] = '</div>';

                    $content[] = '<div class="ays-pd-dicount-wrap-box">';

                        $content[] = '<div id="ays-pd-countdown-main-container">';
                            $content[] = '<div class="ays-pd-countdown-container">';

                                $content[] = '<div id="ays-pd-countdown">';
                                    $content[] = '<ul>';
                                        $content[] = '<li><span id="ays-pd-countdown-days"></span>days</li>';
                                        $content[] = '<li><span id="ays-pd-countdown-hours"></span>Hours</li>';
                                        $content[] = '<li><span id="ays-pd-countdown-minutes"></span>Minutes</li>';
                                        $content[] = '<li><span id="ays-pd-countdown-seconds"></span>Seconds</li>';
                                    $content[] = '</ul>';
                                $content[] = '</div>';

                                $content[] = '<div id="ays-pd-countdown-content" class="emoji">';
                                    $content[] = '<span>🚀</span>';
                                    $content[] = '<span>⌛</span>';
                                    $content[] = '<span>🔥</span>';
                                    $content[] = '<span>💣</span>';
                                $content[] = '</div>';

                            $content[] = '</div>';                           

                        $content[] = '</div>';
                            
                    $content[] = '</div>';

                    $content[] = '<div class="ays-pd-dicount-wrap-box ays-buy-now-button-box">';
                        $content[] = '<a href="https://ays-pro.com/school-bundle" class="button button-primary ays-buy-now-button" id="ays-button-top-buy-now" target="_blank" style="" >' . __( 'Buy Now !', PERSONAL_DICTIONARY_NAME ) . '</a>';
                    $content[] = '</div>';              

                $content[] = '</div>';

                $content[] = '<div style="position: absolute;right: 0;bottom: 1px;" class="ays-pd-dismiss-buttons-container-for-form">';
                    $content[] = '<form action="" method="POST">';
                        $content[] = '<div id="ays-pd-dismiss-buttons-content">';                         
                            $content[] = '<button class="btn btn-link ays-button" name="ays_pd_sale_btn" style="height: 32px; margin-left: 0;padding-left: 0; color: #979797;">Dismiss ad</button>';
                        $content[] = '</div>';
                    $content[] = '</form>';
                $content[] = '</div>';

            $content[] = '</div>';

            $content = implode( '', $content );
            echo $content;
        }
    }	

	function ays_pd_sale_message($ishmar){
		if($ishmar == 0 ){
			$content[] = '<div id="ays-pd-dicount-month-main" class="notice notice-success is-dismissible ays_pd_dicount_info">';
				$content[] = '<div id="ays-pd-dicount-month" class="ays_pd_dicount_month">';
					$content[] = '<a href="https://ays-pro.com/business-bundle" target="_blank" class="ays-pd-sale-banner-link" style="display:none;"><img src="' . PERSONAL_DICTIONARY_ADMIN_URL . '/images/black-friday-great-bundle.png"></a>';

					$content[] = '<div class="ays-pd-dicount-wrap-box">';

						$content[] = '<strong style="font-weight: bold;">';
							$content[] = __( "Limited Time <span class='ays-pd-dicount-wrap-color'>50%</span> SALE on <br><span><a href='https://ays-pro.com/business-bundle' target='_blank' class='ays-pd-dicount-wrap-color ays-pd-dicount-wrap-text-decoration' style='display:block;'>Business Bundle</a></span> (All 13 Plugins)!", PERSONAL_DICTIONARY_NAME );
						$content[] = '</strong>';

						$content[] = '<br>';

						$content[] = '<strong>';
								$content[] = __( "Hurry up! Ends on November 26. <a href='https://ays-pro.com/business-bundle' target='_blank'>Check it out!</a>", PERSONAL_DICTIONARY_NAME );
						$content[] = '</strong>';
							
					$content[] = '</div>';

					$content[] = '<div class="ays-pd-dicount-wrap-box">';

						$content[] = '<div id="ays-pd-countdown-main-container">';
							$content[] = '<div class="ays-pd-countdown-container">';

								$content[] = '<div id="ays-pd-countdown">';
									$content[] = '<ul>';
										$content[] = '<li><span id="ays-pd-countdown-days"></span>days</li>';
										$content[] = '<li><span id="ays-pd-countdown-hours"></span>Hours</li>';
										$content[] = '<li><span id="ays-pd-countdown-minutes"></span>Minutes</li>';
										$content[] = '<li><span id="ays-pd-countdown-seconds"></span>Seconds</li>';
									$content[] = '</ul>';
								$content[] = '</div>';

								$content[] = '<div id="ays-pd-countdown-content" class="emoji">';
									$content[] = '<span>🚀</span>';
									$content[] = '<span>⌛</span>';
									$content[] = '<span>🔥</span>';
									$content[] = '<span>💣</span>';
								$content[] = '</div>';

							$content[] = '</div>';

							$content[] = '<form action="" method="POST">';
								$content[] = '<div id="ays-pd-dismiss-buttons-content">';
									$content[] = '<button class="btn btn-link ays-button" name="ays_pd_sale_btn_winter" style="height: 32px; margin-left: 0;padding-left: 0">Dismiss ad</button>';
									$content[] = '<button class="btn btn-link ays-button" name="ays_pd_sale_btn_winter_for_two_months" style="height: 32px; margin-left: 0;padding-left: 0">Dismiss ad for 2 months</button>';
								$content[] = '</div>';
							$content[] = '</form>';

						$content[] = '</div>';
							
					$content[] = '</div>';

					$content[] = '<div class="ays-pd-dicount-wrap-box ays-buy-now-button-box">';
						$content[] = '<a href="https://ays-pro.com/business-bundle" class="button button-primary ays-buy-now-button" id="ays-button-top-buy-now" target="_blank" style="" >' . __( 'Buy Now !', PERSONAL_DICTIONARY_NAME ) . '</a>';
					$content[] = '</div>';

					$content[] = '<div class="ays-pd-dicount-wrap-box ays-pd-dicount-wrap-opacity-box">';
						$content[] = '<a href="https://ays-pro.com/business-bundle" class="ays-buy-now-opacity-button" target="_blank">' . __( 'link', PERSONAL_DICTIONARY_NAME ) . '</a>';
					$content[] = '</div>';

				$content[] = '</div>';
			$content[] = '</div>';
			
			$content = implode( '', $content );
			echo $content;
		}
	}

	// public function ays_pd_winter_bundle_message($ishmar){
    //     if($ishmar == 0 ){
    //         $content = array();

    //         $content[] = '<div id="ays-pd-dicount-month-main" class="notice notice-success is-dismissible ays_pd_dicount_info">';
    //             $content[] = '<div id="ays-pd-dicount-month" class="ays_pd_dicount_month">';
    //                 $content[] = '<a href="https://ays-pro.com/winter-bundle" target="_blank" class="ays-pd-sale-banner-link"><img src="' . PERSONAL_DICTIONARY_ADMIN_URL . '/images/winter_bundle_logo.png"></a>';

    //                 $content[] = '<div class="ays-pd-dicount-wrap-box">';

    //                     $content[] = '<strong>';
    //                         $content[] = __( "Limited Time <span class='ays-pd-dicount-wrap-color'>50%</span> SALE on <br><span><a href='https://ays-pro.com/winter-bundle' target='_blank' class='ays-pd-dicount-wrap-color ays-pd-dicount-wrap-text-decoration' style='display:block;'>Winter Bundle</a></span> (Copy + Popup + Survey)!", PERSONAL_DICTIONARY_NAME );
    //                     $content[] = '</strong>';

    //                     $content[] = '<br>';

    //                     $content[] = '<strong>';
    //                             $content[] = __( "Hurry up! Ends on January 1. <a href='https://ays-pro.com/winter-bundle' target='_blank'>Check it out!</a>", PERSONAL_DICTIONARY_NAME );
    //                     $content[] = '</strong>';
                            
    //                 $content[] = '</div>';

    //                 $content[] = '<div class="ays-pd-dicount-wrap-box">';

    //                     $content[] = '<div id="ays-pd-countdown-main-container">';
    //                         $content[] = '<div class="ays-pd-countdown-container">';

    //                             $content[] = '<div id="ays-pd-countdown">';
    //                                 $content[] = '<ul>';
    //                                     $content[] = '<li><span id="ays-pd-countdown-days"></span>days</li>';
    //                                     $content[] = '<li><span id="ays-pd-countdown-hours"></span>Hours</li>';
    //                                     $content[] = '<li><span id="ays-pd-countdown-minutes"></span>Minutes</li>';
    //                                     $content[] = '<li><span id="ays-pd-countdown-seconds"></span>Seconds</li>';
    //                                 $content[] = '</ul>';
    //                             $content[] = '</div>';

    //                             $content[] = '<div id="ays-pd-countdown-content" class="emoji">';
    //                                 $content[] = '<span>🚀</span>';
    //                                 $content[] = '<span>⌛</span>';
    //                                 $content[] = '<span>🔥</span>';
    //                                 $content[] = '<span>💣</span>';
    //                             $content[] = '</div>';

    //                         $content[] = '</div>';

    //                         $content[] = '<form action="" method="POST">';
	// 							$content[] ='<div id="ays-pd-dismiss-buttons-content" style="margin: auto;display:flex;">';
	// 								$content[] = '<button class="btn btn-link ays-button" name="ays_pd_sale_btn_winter" style="height: 32px; margin-left: 0;padding-left: 0;cursor:pointer;">Dismiss ad</button>';
	// 								$content[] = '<button class="btn btn-link ays-button" name="ays_pd_sale_btn_winter_for_two_months" style="height: 32px; padding-left: 0;margin-left:5px; cursor:pointer;">Dismiss ad for 2 months</button>';
	// 							$content[] ='</div>';
    //                         $content[] = '</form>';

    //                     $content[] = '</div>';
                            
    //                 $content[] = '</div>';

    //                 $content[] = '<a href="https://ays-pro.com/winter-bundle" class="button button-primary ays-button" id="ays-button-top-buy-now" target="_blank">' . __( 'Buy Now !', PERSONAL_DICTIONARY_NAME ) . '</a>';
    //             $content[] = '</div>';
    //         $content[] = '</div>';

    //         $content = implode( '', $content );
    //         echo $content;
    //     }
    // }

    public function ays_pd_summer_bundle_message($ishmar){
        if($ishmar == 0 ){
            $content = array();

            $content[] = '<div id="ays-pd-dicount-month-main" class="notice notice-success is-dismissible ays_pd_dicount_info">';
                $content[] = '<div id="ays-pd-dicount-month" class="ays_pd_dicount_month">';
                	$content[] = '<div>';
	                    $content[] = '<a href="https://ays-pro.com/wordpress/personal-dictionary" target="_blank" class="ays-pd-sale-banner-link"><img src="' . PERSONAL_DICTIONARY_ADMIN_URL . '/images/icons/pd-logo-128x128.png"></a>';
						$content[] = '<p class="ays-pd-logo-subtitle">';                    
							$content[] = __("Personal Dictionary");
						 $content[] = '</p>'; 
					 $content[] = '</div>';
					 	
                    $content[] = '<div class="ays-pd-dicount-wrap-box ays-pd-summer-sale">';
                        $content[] = '<a href="https://ays-pro.com/wordpress/personal-dictionary" target="_blank"><img src="' . PERSONAL_DICTIONARY_ADMIN_URL . '/images/pd-summer-sale.png"></a>';                                
                    $content[] = '</div>';

                    $content[] = '<div class="ays-pd-dicount-wrap-box ays-pd-divider">';
                              
                    $content[] = '</div>';

                    $content[] = '<div class="ays-pd-dicount-wrap-box">';
                        $content[] = '<p>';
                                $content[] = __( "Create an Online Vocabulary with Advances Features via <br> <a href='https://ays-pro.com/wordpress/personal-dictionary' target='_blank'> Personal Dictionary Pro version</a>", PERSONAL_DICTIONARY_NAME );
                        $content[] = '</p>';                                
                    $content[] = '</div>';

                    $content[] = '<div>';
	                    $content[] = '<a href="https://ays-pro.com/wordpress/personal-dictionary" class="button button-primary ays-button" id="ays-button-top-buy-now" target="_blank">' . __( 'Buy Now !', PERSONAL_DICTIONARY_NAME ) . '</a>';
	                    $content[] = '<form action="" method="POST">';
	                    	$content[] = '<button class="ays-pd-dismiss-button" name="ays_pd_sale_btn_winter" style="height: 32px; margin-left: 0;padding-left: 0;cursor:pointer; margin: auto;">Dismiss ad</button>';
	                    $content[] = '</form>';
                    $content[] = '</div>';
                $content[] = '</div>';
            $content[] = '</div>';

            $content = implode( '', $content );
            echo $content;
        }
    }

	// Christmas banner
    public static function ays_pd_christmas_message($ishmar){
        if($ishmar == 0 ){
            $content = array();

            $content[] = '<div id="ays-pd-dicount-christmas-month-main" class="notice notice-success is-dismissible ays_pd_dicount_info">';
                $content[] = '<div id="ays-pd-dicount-christmas-month" class="ays_pd_dicount_month">';
                    $content[] = '<div class="ays-pd-dicount-christmas-box">';
                        $content[] = '<div class="ays-pd-dicount-christmas-wrap-box ays-pd-dicount-christmas-wrap-box-80">';
                            $content[] = '<div class="ays-pd-dicount-christmas-title-row">' . __( 'Limited Time', PERSONAL_DICTIONARY_NAME ) .' '. '<a href="https://ays-pro.com/wordpress/personal-dictionary" class="ays-pd-dicount-christmas-button-sale" target="_blank">' . __( '20%', PERSONAL_DICTIONARY_NAME ) . '</a>' . ' SALE</div>';
                            $content[] = '<div class="ays-pd-dicount-christmas-title-row">' . __( 'Personal Dictionary Plugin', PERSONAL_DICTIONARY_NAME ) . '</div>';
                        $content[] = '</div>';

                        $content[] = '<div class="ays-pd-dicount-christmas-wrap-box" style="width: 25%;">';
                            $content[] = '<div id="ays-pd-countdown-main-container">';
                                $content[] = '<div class="ays-pd-countdown-container">';
                                    $content[] = '<div id="ays-pd-countdown" style="display: block;">';
                                        $content[] = '<ul>';
                                            $content[] = '<li><span id="ays-pd-countdown-days"></span>' . __( 'Days', PERSONAL_DICTIONARY_NAME ) . '</li>';
                                            $content[] = '<li><span id="ays-pd-countdown-hours"></span>' . __( 'Hours', PERSONAL_DICTIONARY_NAME ) . '</li>';
                                            $content[] = '<li><span id="ays-pd-countdown-minutes"></span>' . __( 'Minutes', PERSONAL_DICTIONARY_NAME ) . '</li>';
                                            $content[] = '<li><span id="ays-pd-countdown-seconds"></span>' . __( 'Seconds', PERSONAL_DICTIONARY_NAME ) . '</li>';
                                        $content[] = '</ul>';
                                    $content[] = '</div>';
                                    $content[] = '<div id="ays-pd-countdown-content" class="emoji" style="display: none;">';
                                        $content[] = '<span>🚀</span>';
                                        $content[] = '<span>⌛</span>';
                                        $content[] = '<span>🔥</span>';
                                        $content[] = '<span>💣</span>';
                                    $content[] = '</div>';
                                $content[] = '</div>';
                            $content[] = '</div>';
                        $content[] = '</div>';

                        $content[] = '<div class="ays-pd-dicount-christmas-wrap-box" style="width: 25%;">';
                            $content[] = '<a href="https://ays-pro.com/wordpress/personal-dictionary" class="ays-pd-dicount-christmas-button-buy-now" target="_blank">' . __( 'BUY NOW!', PERSONAL_DICTIONARY_NAME ) . '</a>';
                        $content[] = '</div>';
                    $content[] = '</div>';
                $content[] = '</div>';

                $content[] = '<div style="position: absolute;right: 0;bottom: 1px;"  class="ays-pd-dismiss-buttons-container-for-form-christmas">';
                    $content[] = '<form action="" method="POST">';
                        $content[] = '<div id="ays-pd-dismiss-buttons-content-christmas">';
                            $content[] = '<button class="btn btn-link ays-button-christmas" name="ays_pd_sale_btn" style="">' . __( 'Dismiss ad', PERSONAL_DICTIONARY_NAME ) . '</button>';
                        $content[] = '</div>';
                    $content[] = '</form>';
                $content[] = '</div>';
            $content[] = '</div>';

            $content = implode( '', $content );

            echo $content;
        }
    }

	//==== ADD PAGES ====
	// Main page
	public function display_plugin_pd_main_page(){
		include_once('partials/dictionaries/personal-dictionary-dictionaries-display.php');
    }
	// Reports page
	public function display_plugin_pd_reports_page(){        
		include_once('partials/reports/personal-dictionary-reports-display.php');
    }
	// Leaderboard page
	public function display_plugin_pd_leaderboard_page(){        
		include_once('partials/leaderboards/personal-dictionary-leaderboards-display.php');
    }
	// Settings page
	public function display_plugin_pd_settings_page(){
		include_once('partials/settings/personal-dictionary-settings-display.php');
    }
	// How to use page
	public function display_plugin_pd_how_to_use_page(){
		include_once('partials/how-to-use/personal-dictionary-how-to-use-display.php');
	}
	// Our products page
	public function display_plugin_pd_our_products_page(){
		include_once('partials/features/personal-dictionary-products-display.php');
    }
	// PRO features page
	public function display_plugin_pd_pro_features_page(){
		include_once('partials/features/personal-dictionary-pro-features-display.php');

    }

	public function deactivate_plugin_option(){
        $request_value = $_REQUEST['upgrade_plugin'];
        $upgrade_option = get_option( 'ays_personal_dictionary_upgrade_plugin', '' );
        if($upgrade_option === ''){
            add_option( 'ays_personal_dictionary_upgrade_plugin', $request_value );
        }else{
            update_option( 'ays_personal_dictionary_upgrade_plugin', $request_value );
        }
        ob_end_clean();
        $ob_get_clean = ob_get_clean();
        echo json_encode( array( 'option' => get_option( 'ays_personal_dictionary_upgrade_plugin', '' ) ) );
        wp_die();
    }

    public function ays_pd_update_banner_time(){

        $date = time() + ( 3 * 24 * 60 * 60 ) + (int) ( get_option( 'gmt_offset' ) * HOUR_IN_SECONDS);
        // $date = time() + ( 60 ) + (int) ( get_option( 'gmt_offset' ) * HOUR_IN_SECONDS); // for testing | 1 min
        $next_3_days = date('M d, Y H:i:s', $date);

        $ays_pd_banner_time = get_option('ays_pd_banner_time');

        if ( !$ays_pd_banner_time || is_null( $ays_pd_banner_time ) ) {
            update_option('ays_pd_banner_time', $next_3_days ); 
        }

        $get_ays_pd_banner_time = get_option('ays_pd_banner_time');

        $val = 60*60*24*0.5; // half day
        // $val = 60; // for testing | 1 min

        $current_date = current_time( 'mysql' );
        $date_diff = strtotime($current_date) - intval(strtotime($get_ays_pd_banner_time));

        $days_diff = $date_diff / $val;
        if(intval($days_diff) > 0 ){
            update_option('ays_pd_banner_time', $next_3_days);
        }

        return $get_ays_pd_banner_time;
    }

}
